import { Dispatch, MutableRefObject, SetStateAction, useCallback } from 'react';
import { NsButton, NsTypography } from '../..';

type SeeMoreButtonProps = {
    text?: string;
    show?: boolean;
    onSeeMore?(): void;
    options: any[];
    setScrollTopPosition: Dispatch<SetStateAction<number>>;
    listboxRef: MutableRefObject<HTMLUListElement | null>;
};

export const SeeMoreButton = (props: SeeMoreButtonProps) => {
    const {
        show = false,
        text = 'See More Results',
        onSeeMore,
        options,
        listboxRef,
        setScrollTopPosition,
    } = props || {};

    const handleSeeMore = useCallback(() => {
        /*  Remember the current scroll position */
        if (options?.length > 0 && listboxRef?.current) {
            const lastScrollPosition = listboxRef.current?.scrollTop;
            if (lastScrollPosition) {
                setScrollTopPosition(lastScrollPosition);
            }
        }
        if (onSeeMore && typeof onSeeMore === 'function') {
            onSeeMore();
        }
    }, [listboxRef, onSeeMore, options?.length, setScrollTopPosition]);
    if (!show) {
        return null;
    }
    return (
        <li className="text-center p-3">
            <NsButton onClick={handleSeeMore} data-testid="autocomplete-loadmore-id">
                <NsTypography variant="p-xs" weight="bold">
                    {text}
                </NsTypography>
            </NsButton>
        </li>
    );
};
